#[non_exhaustive]pub struct ResizeEdge(pub u32);Expand description
edge values for resizing
These values are used to indicate which edge of a surface is being dragged in a resize operation.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: u32Implementations