#[non_exhaustive]pub struct State(pub u32);Expand description
types of state on the surface
The different state values used on the surface. This is designed for state values like maximized, fullscreen. It is paired with the configure event to ensure that both the client and the compositor setting the state can be synchronized.
States set in this way are double-buffered, see wl_surface.commit.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: u32Implementations
Sourceimpl State
impl State
Sourcepub const Maximized: Self
pub const Maximized: Self
the surface is maximized
The surface is maximized. The window geometry specified in the configure event must be obeyed by the client, or the xdg_wm_base.invalid_surface_state error is raised.
The client should draw without shadow or other decoration outside of the window geometry.
Sourcepub const Fullscreen: Self
pub const Fullscreen: Self
the surface is fullscreen
The surface is fullscreen. The window geometry specified in the configure event is a maximum; the client cannot resize beyond it. For a surface to cover the whole fullscreened area, the geometry dimensions must be obeyed by the client. For more details, see xdg_toplevel.set_fullscreen.
Sourcepub const Resizing: Self
pub const Resizing: Self
the surface is being resized
The surface is being resized. The window geometry specified in the configure event is a maximum; the client cannot resize beyond it. Clients that have aspect ratio or cell sizing configuration can use a smaller size, however.
Sourcepub const Activated: Self
pub const Activated: Self
the surface is now activated
Client window decorations should be painted as if the window is active. Do not assume this means that the window actually has keyboard or pointer focus.
Sourcepub const TiledLeft: Self
pub const TiledLeft: Self
the surface’s left edge is tiled
The window is currently in a tiled layout and the left edge is considered to be adjacent to another part of the tiling grid.
The client should draw without shadow or other decoration outside of the window geometry on the left edge.
Sourcepub const TiledRight: Self
pub const TiledRight: Self
the surface’s right edge is tiled
The window is currently in a tiled layout and the right edge is considered to be adjacent to another part of the tiling grid.
The client should draw without shadow or other decoration outside of the window geometry on the right edge.
Sourcepub const TiledTop: Self
pub const TiledTop: Self
the surface’s top edge is tiled
The window is currently in a tiled layout and the top edge is considered to be adjacent to another part of the tiling grid.
The client should draw without shadow or other decoration outside of the window geometry on the top edge.
Sourcepub const TiledBottom: Self
pub const TiledBottom: Self
the surface’s bottom edge is tiled
The window is currently in a tiled layout and the bottom edge is considered to be adjacent to another part of the tiling grid.
The client should draw without shadow or other decoration outside of the window geometry on the bottom edge.
Sourcepub const Suspended: Self
pub const Suspended: Self
surface repaint is suspended
The surface is currently not ordinarily being repainted; for example because its content is occluded by another window, or its outputs are switched off due to screen locking.
Sourcepub const ConstrainedLeft: Self
pub const ConstrainedLeft: Self
the surface’s left edge is constrained
The left edge of the window is currently constrained, meaning it shouldn’t attempt to resize from that edge. It can for example mean it’s tiled next to a monitor edge on the constrained side of the window.
Sourcepub const ConstrainedRight: Self
pub const ConstrainedRight: Self
the surface’s right edge is constrained
The right edge of the window is currently constrained, meaning it shouldn’t attempt to resize from that edge. It can for example mean it’s tiled next to a monitor edge on the constrained side of the window.
Sourcepub const ConstrainedTop: Self
pub const ConstrainedTop: Self
the surface’s top edge is constrained
The top edge of the window is currently constrained, meaning it shouldn’t attempt to resize from that edge. It can for example mean it’s tiled next to a monitor edge on the constrained side of the window.
Sourcepub const ConstrainedBottom: Self
pub const ConstrainedBottom: Self
the surface’s bottom edge is constrained
The bottom edge of the window is currently constrained, meaning it shouldn’t attempt to resize from that edge. It can for example mean it’s tiled next to a monitor edge on the constrained side of the window.